@@ -1,4 +1,4 @@
-(* $Id: delcol.ml,v 1.3 2001/06/29 11:13:44 gerd Exp $
+(* $Id: delcol.ml 745 2009-02-02 21:23:48Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
@@ -6,7 +6,7 @@
 (* Read a record-list, delete a column, and print it as XML *)
 open Pxp_types;;
 open Pxp_document;;
-open Pxp_yacc;;
+open Pxp_tree_parser;;
 
 let delcol col tree =
   map_tree
@@ -37,7 +37,8 @@ let main() =
     exit 1
   );
   try
-    let dtd = parse_dtd_entity default_config (from_file "record.dtd") in
+    let dtd = 
+      Pxp_dtd_parser.parse_dtd_entity default_config (from_file "record.dtd") in
     let tree = 
       parse_content_entity default_config (from_channel stdin) dtd default_spec
     in
@@ -52,18 +53,3 @@ let main() =
 
 main();;
 
-(* ======================================================================
- * History:
- * 
- * $Log: delcol.ml,v $
- * Revision 1.3  2001/06/29 11:13:44  gerd
- * 	Out_channel -> `Out_channel
- *
- * Revision 1.2  2000/08/24 09:42:52  gerd
- * 	Updated a comment.
- *
- * Revision 1.1  2000/08/24 09:39:59  gerd
- * 	Initial revision.
- *
- * 
- *)
