@@ -1,11 +1,11 @@
-(* $Id: ds_context.ml 662 2004-05-25 20:57:28Z gerd $
+(* $Id: ds_context.ml 745 2009-02-02 21:23:48Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
 
 open Pxp_types
 open Pxp_document
-open Pxp_yacc
+open Pxp_tree_parser
 
 let empty_record = new element_impl (Pxp_yacc.default_extension);;
 let empty_dnode = new data_impl Pxp_yacc.default_extension;;
