@@ -1,4 +1,4 @@
-(* $Id: pxp_core_parser.mli 707 2004-09-04 17:25:35Z gerd $
+(* $Id: pxp_core_parser.mli 741 2009-02-02 17:11:36Z gerd $
  * ----------------------------------------------------------------------
  * PXP: The polymorphic XML parser for Objective Caml.
  * Copyright by Gerd Stolpmann. See LICENSE for details.
@@ -67,6 +67,7 @@ object
   val mutable pull_counter : int
   val mutable p_internal_subset : bool
   val mutable ns_scope : Pxp_dtd.namespace_scope option
+  val mutable permit_any_content : bool
 
   method parse : context -> extended_entry -> unit
 
@@ -81,7 +82,7 @@ object
 
   method private pop_src_norm_mapping : unit -> unit
 
-  method private virtual init_for_xml_body : unit -> unit
+  method private virtual init_for_xml_body : entity_id -> unit
 
   method private virtual event_document_xmldecl : 
                              Pxp_lexer_types.prolog_token list -> unit
